﻿using System;
using System.Text;
using System.Collections.Generic;
using System.Linq;
using Microsoft.VisualStudio.TestTools.UnitTesting;
using ServiceTrackerLogic;

namespace ServiceTrackerLogicTests
{
	/// <summary>
	/// Summary description for AccountTests
	/// </summary>
	[TestClass]
	public class AccountTests
	{
		[TestMethod]
		public void FactoryMethodCreatesAccountWithCorrectInformation()
		{
            IAccount account = Account.CreateAccount("My User", "813-111-2222");
			account.Address = "12345 Blah Circle";
			account.City = "Tampa";
			account.State = "FL";
			account.ZipCode = "12345";

			Account createdAccount = Account.CreateAccount(account);
			Assert.AreEqual(account as Account, createdAccount);
		}

        [TestMethod]
        public void TwoAccountsFromFactoryWithMatchingNameAndPhoneAreEqual()
        {
            Account account1 = Account.CreateAccount("Test User", "813-555-1234");
            Account account2 = Account.CreateAccount("Test User", "813-555-1234");
            Assert.AreEqual(account1, account2);
        }

        [TestMethod]
        [ExpectedException(typeof(ArgumentException))]
        public void CreatingAccountWithNameAsEmptyStringThrowsArgumentException()
        {
            Account a = Account.CreateAccount(String.Empty, "813-555-1212");
        }

        [TestMethod]
        [ExpectedException(typeof(ArgumentException))]
        public void CreatingAccountWithNullNameThrowsArgumentException()
        {
            Account a = Account.CreateAccount(null, "813-555-1212");
        }

        [TestMethod]
        [ExpectedException(typeof(ArgumentException))]
        public void CreatingAccountWithNameOnlySpacesThrowsArgumentException()
        {
            Account a = Account.CreateAccount(" ", "813-555-1212");
        }

        [TestMethod]
        [ExpectedException(typeof(ArgumentException))]
        public void CreatingAccountWithPhoneAsEmptyStringThrowsArgumentException()
        {
            Account a = Account.CreateAccount("Test User", "");
        }

        [TestMethod]
        [ExpectedException(typeof(ArgumentException))]
        public void CreatingAccountWithNullPhoneThrowsArgumentException()
        {
            Account a = Account.CreateAccount("Test User", null);
        }

        [TestMethod]
        [ExpectedException(typeof(ArgumentException))]
        public void CreatingAccountWithPhoneOnlySpacesThrowsArgumentException()
        {
            Account a = Account.CreateAccount("Test User", " ");
        }

        [TestMethod]
        public void CreatingAccountWithCorrectlyFormattedPhoneDoesNotThrowException()
        {
            Account a = Account.CreateAccount("Test User", "(813) 555-1212");
        }

        [TestMethod]
        [ExpectedException(typeof(ArgumentException))]
        public void CreatingAccountWithGarbageFormattedThrowsArgumentException()
        {
            Account a = Account.CreateAccount("Test User", "(gh!) 1TT-**GW");
        }

        [TestMethod]
        public void CreatingAccountAsnnn_nnn_nnnnWorks()
        {
            Account a = Account.CreateAccount("Test User", "813-555-1212");
        }

        [TestMethod]
        public void CreatingAccountWithnnn_nnn_nnnnPhoneStoresInProperFormat()
        {
            Account a = Account.CreateAccount("Test User", "813-555-1212");
            Assert.AreEqual("(813) 555-1212", a.PhoneNumber);
        }
	}
}
