﻿using System;
using System.Text;
using System.Collections.Generic;
using System.Linq;
using Microsoft.VisualStudio.TestTools.UnitTesting;
using ServiceTrackerLogic;

namespace ServiceTrackerLogicTests
{
	/// <summary>
	/// Summary description for UnitTest1
	/// </summary>
	[TestClass]
	public class AccountsTests
	{
		private Account testAccountTestUser;
		private Accounts initializedAccounts;

		[TestInitialize]
		public void Setup()
		{
			testAccountTestUser = Account.CreateAccount("Test User", "813-555-1234");
			initializedAccounts = new Accounts();
			initializedAccounts.Add(testAccountTestUser);
		}

		[TestMethod]
		public void AddingAccountToAccountsIncrementsListCount()
		{
            Account account = Account.CreateAccount("Test User", "813-555-1234");
			Accounts accounts = new Accounts();
			accounts.Add(account);
			Assert.AreEqual(1, accounts.Count);
		}

		[TestMethod]
		public void AddingAccountToAccountsAddsAccountToList()
		{
            Account account = Account.CreateAccount("Test User", "813-555-1234");
			Accounts accounts = new Accounts();
			accounts.Add(account);
			Assert.AreEqual(account, accounts[0]);
		}

		[TestMethod]
		public void SearchingByFullNameReturnsMatchingAccount()
		{
			Accounts foundAccounts = initializedAccounts.FindAccount("Test User");
			Assert.AreEqual(1, foundAccounts.Count);
			Assert.AreEqual(testAccountTestUser, foundAccounts[0]);
		}

		[TestMethod]
		public void SearchingByFullNameWhenMultipleAccountsReturnsOnlyMatchingAccount()
		{
            Account account2 = Account.CreateAccount("Justin Example", "813-555-1212");
			initializedAccounts.Add(account2);
			Accounts foundAccounts = initializedAccounts.FindAccount("Test User");
			Assert.AreEqual(1, foundAccounts.Count);
			Assert.AreEqual(testAccountTestUser, foundAccounts[0]);
		}

		[TestMethod]
		public void SearchingByFullPhoneNumberReturnsMatchingAccount()
		{
			Accounts foundAccounts = initializedAccounts.FindAccount("813-555-1234");
			Assert.AreEqual(1, foundAccounts.Count);
			Assert.AreEqual(testAccountTestUser, foundAccounts[0]);
		}

		[TestMethod]
		public void SearchingByFullPhoneWhenMultipleAccountsReturnsOnlyMatchingAccount()
		{
            Account account2 = Account.CreateAccount("Justin Example", "813-555-1212");
			initializedAccounts.Add(account2);
			Accounts foundAccounts = initializedAccounts.FindAccount("813-555-1234");
			Assert.AreEqual(1, foundAccounts.Count);
			Assert.AreEqual(testAccountTestUser, foundAccounts[0]);
		}

		[TestMethod]
		public void SearchingByCharactersAtBeginningOfNameFindsAccount()
		{
			Accounts foundAccounts = initializedAccounts.FindAccount("Tes");
			Assert.AreEqual(1, foundAccounts.Count);
			Assert.AreEqual(testAccountTestUser, foundAccounts[0]);
		}

		[TestMethod]
		public void SearchingByCharactersInMiddleOfNameFindsAccount()
		{
			Accounts foundAccounts = initializedAccounts.FindAccount("st");
			Assert.AreEqual(1, foundAccounts.Count);
			Assert.AreEqual(testAccountTestUser, foundAccounts[0]);
		}

		[TestMethod]
		public void SearchingByCharactersAtEndOfNameFindsAccount()
		{
			Accounts foundAccounts = initializedAccounts.FindAccount("User");
			Assert.AreEqual(1, foundAccounts.Count);
			Assert.AreEqual(testAccountTestUser, foundAccounts[0]);
		}

		[TestMethod]
		public void SearchingByCharactersAtBeginningOfPhoneFindsAccount()
		{
			Accounts foundAccounts = initializedAccounts.FindAccount("813");
			Assert.AreEqual(1, foundAccounts.Count);
			Assert.AreEqual(testAccountTestUser, foundAccounts[0]);
		}

		[TestMethod]
		public void SearchingByCharactersInMiddleOfPhoneFindsAccount()
		{
			Accounts foundAccounts = initializedAccounts.FindAccount("555");
			Assert.AreEqual(1, foundAccounts.Count);
			Assert.AreEqual(testAccountTestUser, foundAccounts[0]);
		}

		[TestMethod]
		public void SearchingByCharactersAtEndOfPhoneFindsAccount()
		{
			Accounts foundAccounts = initializedAccounts.FindAccount("1234");
			Assert.AreEqual(1, foundAccounts.Count);
			Assert.AreEqual(testAccountTestUser, foundAccounts[0]);
		}

		[TestMethod]
		public void AccountsCollectionNotifiesListenersWhenAdded()
		{
			Accounts accounts = initializedAccounts;
			bool updatedFired = false;
			accounts.CollectionChanged += delegate { updatedFired = true; };
            accounts.Add(Account.CreateAccount("Blah", "555-111-1212"));
			Assert.IsTrue(updatedFired);
		}
	}
}
