﻿using System;
using System.Text;
using System.Collections.Generic;
using System.Linq;
using Microsoft.VisualStudio.TestTools.UnitTesting;
using ServiceTrackerLogic;

namespace ServiceTrackerLogicTests
{
    /// <summary>
    /// Summary description for PhoneNumberTests
    /// </summary>
    [TestClass]
    public class PhoneNumberTests
    {
        [TestMethod]
        [ExpectedException(typeof(ArgumentException))]
        public void CreatingPhoneNumberWithPhoneAsEmptyStringThrowsArgumentException()
        {
            PhoneNumber pn = new PhoneNumber("");
        }

        [TestMethod]
        [ExpectedException(typeof(ArgumentException))]
        public void CreatingPhoneNumberWithNullPhoneThrowsArgumentException()
        {
            PhoneNumber pn = new PhoneNumber(null);
        }

        [TestMethod]
        [ExpectedException(typeof(ArgumentException))]
        public void CreatingPhoneNumberWithPhoneOnlySpacesThrowsArgumentException()
        {
            PhoneNumber pn = new PhoneNumber(" ");
        }

        [TestMethod]
        public void CreatingPhoneNumberWithCorrectlyFormattedPhoneDoesNotThrowException()
        {
            PhoneNumber pn = new PhoneNumber("(813) 555-1212");
        }

        [TestMethod]
        [ExpectedException(typeof(ArgumentException))]
        public void CreatingPhoneNumberWithGarbageFormattedThrowsArgumentException()
        {
            PhoneNumber pn = new PhoneNumber("(gh!) 1TT-**GW");
        }

        [TestMethod]
        public void CreatingPhoneNumberAsnnn_nnn_nnnnWorks()
        {
            PhoneNumber pn = new PhoneNumber("813-555-1212");
        }

        [TestMethod]
        public void CreatingPhoneNumberWithnnn_nnn_nnnnPhoneStoresInProperFormat()
        {
            PhoneNumber pn = new PhoneNumber("813-555-1212");
            Assert.AreEqual("(813) 555-1212", pn.ToString());
        }

        [TestMethod]
        public void AlternateFormatReturnsCorrectNumberFromnnn_nnn_nnnn()
        {
            PhoneNumber pn = new PhoneNumber("813-555-1212");
            Assert.AreEqual("813-555-1212", pn.AlternateFormat);
        }

        [TestMethod]
        public void AlternateFormatReturnsCorrectNumberFromParenFormat()
        {
            PhoneNumber pn = new PhoneNumber("(813) 555-1212");
            Assert.AreEqual("813-555-1212", pn.AlternateFormat);
        }
    }
}
