﻿using System;
using System.Text;
using System.Collections.Generic;
using System.Linq;
using Microsoft.VisualStudio.TestTools.UnitTesting;
using ServiceTrackerPresenter;
using ServiceTrackerLogic;

namespace ServiceTrackerPresenterTests
{
	/// <summary>
	/// Summary description for AddAccountPresenterTests
	/// </summary>
	[TestClass]
	public class AddAccountPresenterTests
	{
		[TestCleanup]
		public void TearDown()
		{
			//Clean up AccountStore
			Accounts.AccountStore = null;
		}

		[TestMethod]
		public void PresenterRegistersAsListenerForAccountReadyForCreation()
		{
			IAddAccountView view = new StubAddAccountView();
			Assert.AreEqual(0, 
				((StubAddAccountView)view).AccountReadyForCreationListenerCount);
			AddAccountPresenter presenter = new AddAccountPresenter(view);
			int expectedListenersCount = 1;
			int actualListenersCount =
				((StubAddAccountView)view).AccountReadyForCreationListenerCount;
			Assert.AreEqual(expectedListenersCount, actualListenersCount);
		}

		[TestMethod]
		public void ValidAccountGetsAddedToAccountsOnSubmit()
		{
			IAddAccountView view = new StubAddAccountView();
			view.AccountName = "Testing Account";
			view.PhoneNumber = "813-555-1212";
			AddAccountPresenter presenter = new AddAccountPresenter(view);
			((StubAddAccountView)view).FireAccountReadyForCreationEvent();
			Assert.AreEqual(3, Accounts.AccountStore.Count);
            Assert.IsTrue(Accounts.AccountStore.Contains(Account.CreateAccount("Testing Account", "813-555-1212")));
		}

		[TestMethod]
		public void PresenterCallsCloseAfterValidAccountAdded()
		{
			IAddAccountView view = new StubAddAccountView();
			view.AccountName = "Testing Account";
			view.PhoneNumber = "813-555-1212";
			AddAccountPresenter presenter = new AddAccountPresenter(view);
			((StubAddAccountView)view).FireAccountReadyForCreationEvent();
			Assert.IsTrue(((StubAddAccountView)view).CloseWasCalled);
		}
	}

	class StubAddAccountView : IAddAccountView
	{
		public event AddAccountViewEventDelegate AccountReadyForCreation;
		public bool CloseWasCalled = false;

		public void Close()
		{
			CloseWasCalled = true;
		}	   

		public int AccountReadyForCreationListenerCount
		{
			get 
			{
				if (AccountReadyForCreation != null)
				{
					return AccountReadyForCreation.GetInvocationList().Count();
				}
				return 0; 
			}
		}

		string accountName;
		string phoneNumber;
		string address;
		string city;
		string state;
		string zipCode;

		public string AccountName
		{
			get { return accountName; }
			set { accountName = value; }
		}

		public string PhoneNumber
		{
			get { return phoneNumber; }
			set { phoneNumber = value; }
		}

		public string Address
		{
			get { return address; }
			set { address = value; }
		}

		public string City
		{
			get { return city; }
			set { city = value; }
		}

		public string State
		{
			get { return state; }
			set { state = value; }
		}

		public string ZipCode
		{
			get { return zipCode; }
			set { zipCode = value; }
		}

		public void FireAccountReadyForCreationEvent()
		{
			if (AccountReadyForCreation != null)
				AccountReadyForCreation(this, this);
		}
	}
}
