﻿using System;
using System.Text;
using System.Collections.Generic;
using System.Linq;
using Microsoft.VisualStudio.TestTools.UnitTesting;
using ServiceTracker;
using ServiceTrackerLogic;

namespace ServiceTrackerTests
{
	/// <summary>
	/// Summary description for AddAccountFormTests
	/// </summary>
	[TestClass]
	public class AddAccountFormTests
	{
		[TestCleanup]
		public void TearDown()
		{
			//Clean up AccountStore
			Accounts.AccountStore = null;
		}

		[TestMethod]
        public void AccountReadyForCreationFiredOnAddAccountClick()
        {
	        using (AddAccountForm addAccountForm = new AddAccountForm())
	        {
                addAccountForm.AccountName = "Test User";
                addAccountForm.PhoneNumber = "813-555-1212";
		        bool accountReadyForCreationFired = false;
		        addAccountForm.AccountReadyForCreation += delegate { accountReadyForCreationFired = true; };
		        addAccountForm.Show();
		        addAccountForm.AddAccount.PerformClick();
		        Assert.IsTrue(accountReadyForCreationFired);
	        }
        }

		[TestMethod]
		public void ValidAccountAddedToCollectionOnAddAccountClick()
		{
			using (AddAccountForm addAccountForm = new AddAccountForm())
			{
				addAccountForm.Show();
				addAccountForm.AccountName = "Form Testing";
				addAccountForm.PhoneNumber = "555-112-3344";
				addAccountForm.AddAccount.PerformClick();
			}
            Assert.IsTrue(Accounts.AccountStore.Contains(Account.CreateAccount("Form Testing", "555-112-3344")));
		}

		[TestMethod]
		public void FormClosedAfterValidAccountAddedFromClick()
		{
			using (AddAccountForm addAccountForm = new AddAccountForm())
			{
				addAccountForm.Show();
				Assert.IsTrue(addAccountForm.Visible);
				addAccountForm.AccountName = "Form Testing";
				addAccountForm.PhoneNumber = "555-112-3344";
				addAccountForm.AddAccount.PerformClick();
				Assert.IsFalse(addAccountForm.Visible);
			}
		}
	}
}
